@@ -84,6 +84,7 @@ AH_JOB *AH_Job_MultiTransferBase_new(AB_USER *u,
   GWEN_DB_NODE *dbParams;
   const char *s;
   int userMaxTrans;
+  int maxTransfers;
 
   j=AH_AccountJob_new(isTransfer?"JobMultiTransfer":"JobMultiDebitNote",
                       u, account);
@@ -136,9 +137,11 @@ AH_JOB *AH_Job_MultiTransferBase_new(AB_USER *u,
     userMaxTrans=AH_User_GetMaxTransfersPerJob(u);
   else
     userMaxTrans=AH_User_GetMaxDebitNotesPerJob(u);
-  aj->maxTransfers=GWEN_DB_GetIntValue(dbParams, "maxTransfers", 0, 0);
-  if (aj->maxTransfers==0 || aj->maxTransfers>userMaxTrans)
-    aj->maxTransfers=userMaxTrans;
+  maxTransfers=GWEN_DB_GetIntValue(dbParams, "maxTransfers", 0, 0);
+  if (maxTransfers==0 || maxTransfers>userMaxTrans)
+    AH_Job_SetMaxTransfers(j, userMaxTrans);
+  else
+    AH_Job_SetMaxTransfers(j, maxTransfers);
 
   return j;
 }
@@ -160,30 +163,6 @@ void GWENHYWFAR_CB AH_Job_MultiTransfer_FreeData(void *bp, void *p){
 
 
 
-/* --------------------------------------------------------------- FUNCTION */
-int AH_Job_MultiTransferBase_GetTransferCount(AH_JOB *j){
-  AH_JOB_MULTITRANSFER *aj;
-
-  assert(j);
-  aj=GWEN_INHERIT_GETDATA(AH_JOB, AH_JOB_MULTITRANSFER, j);
-  assert(aj);
-  return aj->transferCount;
-}
-
-
-
-/* --------------------------------------------------------------- FUNCTION */
-int AH_Job_MultiTransferBase_GetMaxTransfers(AH_JOB *j){
-  AH_JOB_MULTITRANSFER *aj;
-
-  assert(j);
-  aj=GWEN_INHERIT_GETDATA(AH_JOB, AH_JOB_MULTITRANSFER, j);
-  assert(aj);
-  return aj->maxTransfers;
-}
-
-
-
 /* --------------------------------------------------------------- FUNCTION */
 int AH_Job_MultiTransfer_Process(AH_JOB *j, AB_IMEXPORTER_CONTEXT *ctx){
   AH_JOB_MULTITRANSFER *aj;
@@ -215,10 +194,7 @@ int AH_Job_MultiTransfer__ValidateTransfer(AB_JOB *bj,
   aj=GWEN_INHERIT_GETDATA(AH_JOB, AH_JOB_MULTITRANSFER, mj);
   assert(aj);
 
-  if (aj->isTransfer)
-    lim=AB_JobSingleTransfer_GetFieldLimits(bj);
-  else
-    lim=AB_JobSingleDebitNote_GetFieldLimits(bj);
+  lim=AB_Job_GetFieldLimits(bj);
 
   /* check purpose */
   if (lim) {
@@ -459,10 +435,7 @@ int AH_Job_MultiTransfer_Exchange(AH_JOB *j, AB_JOB *bj,
                            1, GWEN_StringList_SortModeInt);
     }
 
-    if (aj->isTransfer)
-      AB_JobSingleTransfer_SetFieldLimits(bj, lim);
-    else
-      AB_JobSingleDebitNote_SetFieldLimits(bj, lim);
+    AB_Job_SetFieldLimits(bj, lim);
 
     return 0;
   }
@@ -475,10 +448,7 @@ int AH_Job_MultiTransfer_Exchange(AH_JOB *j, AB_JOB *bj,
     groupIdBuf[0]=0;
     dbArgs=AH_Job_GetArguments(j);
     assert(dbArgs);
-    if (aj->isTransfer)
-      ot=AB_JobSingleTransfer_GetTransaction(bj);
-    else
-      ot=AB_JobSingleDebitNote_GetTransaction(bj);
+    ot=AB_Job_GetTransaction(bj);
     if (ot) {
       GWEN_DB_NODE *dbT;
       AB_TRANSACTION *t;
@@ -500,10 +470,7 @@ int AH_Job_MultiTransfer_Exchange(AH_JOB *j, AB_JOB *bj,
 
       /* store the validated transaction back into application job,
        * to allow the application to recognize answers to this job later */
-      if (aj->isTransfer)
-        AB_JobSingleTransfer_SetTransaction(bj, t);
-      else
-        AB_JobSingleDebitNote_SetTransaction(bj, t);
+      AB_Job_SetTransaction(bj, t);
 
       dbT=GWEN_DB_GetGroup(dbArgs, GWEN_DB_FLAGS_DEFAULT,
                            "transfers");
@@ -579,7 +546,7 @@ int AH_Job_MultiTransfer_Exchange(AH_JOB *j, AB_JOB *bj,
       }
       AB_Transaction_free(t);
 
-      aj->transferCount++;
+      AH_Job_IncTransferCount(j);
     }
     else {
       DBG_ERROR(AQHBCI_LOGDOMAIN, "No transaction");
@@ -643,7 +610,7 @@ int AH_Job_MultiTransfer_Exchange(AH_JOB *j, AB_JOB *bj,
     if (aj->isTransfer) {
       const AB_TRANSACTION *ot;
 
-      ot=AB_JobSingleTransfer_GetTransaction(bj);
+      ot=AB_Job_GetTransaction(bj);
       if (ot) {
 	AB_TRANSACTION *t;
 
@@ -656,7 +623,7 @@ int AH_Job_MultiTransfer_Exchange(AH_JOB *j, AB_JOB *bj,
     else {
       const AB_TRANSACTION *ot;
 
-      ot=AB_JobSingleDebitNote_GetTransaction(bj);
+      ot=AB_Job_GetTransaction(bj);
       if (ot) {
 	AB_TRANSACTION *t;
 
@@ -761,7 +728,7 @@ int AH_Job_MultiTransfer_AddChallengeParams(AH_JOB *j, int hkTanVer, GWEN_DB_NOD
       AH_Job_SetChallengeClass(j, 19);
 
     /* P1: number of transfers */
-    snprintf(numbuf, sizeof(numbuf)-1, "%d", aj->transferCount);
+    snprintf(numbuf, sizeof(numbuf)-1, "%d", AH_Job_GetTransferCount(j));
     numbuf[sizeof(numbuf)-1]=0;
     AH_Job_AddChallengeParam(j, numbuf);
 
